# Python Zana


[![PyPi version][pypi-image]][pypi-link]
[![Supported Python versions][pyversions-image]][pyversions-link]
[![Build status][ci-image]][ci-link]
[![Coverage status][codecov-image]][codecov-link]


A Python tool kit



## Installation

Install from [PyPi](https://pypi.org/project/zana/)

```
pip install zana
```

## Documentation

Full documentation is available [here][docs-link].



## Production

__This package is still in active development and should not be used in production environment__




[docs-link]: https://python-zana.github.io/zana/
[pypi-image]: https://img.shields.io/pypi/v/zana.svg?color=%233d85c6
[pypi-link]: https://pypi.python.org/pypi/zana
[pyversions-image]: https://img.shields.io/pypi/pyversions/zana.svg
[pyversions-link]: https://pypi.python.org/pypi/zana
[ci-image]: https://github.com/python-zana/zana/actions/workflows/workflow.yaml/badge.svg?event=push&branch=main
[ci-link]: https://github.com/python-zana/zana/actions?query=workflow%3ACI%2FCD+event%3Apush+branch%3Amaster
[codecov-image]: https://codecov.io/gh/python-zana/zana/branch/main/graph/badge.svg
[codecov-link]: https://codecov.io/gh/python-zana/zana


See this release on GitHub: [v0.1.3](https://github.com/python-zana/zana/releases/tag/0.1.3)
